@@ -32,10 +32,17 @@ case "$1" in
         chgrp $WWW_GROUP $SERVER_CONFIG
         chmod u=rw,g=r,o= $SERVER_CONFIG
 
-        if [ ! -f "$VAR_DIR/$USER_DB" ];then
-            zcat "/usr/share/doc/benno-web/${USER_DB}.gz" > "$VAR_DIR/$USER_DB"
-            #ln -s "$VAR_DIR/$USER_DB" "$ETC_DIR"
+        set +e
+        if [ -f "$VAR_DIR/$USER_DB" ];then
+            # convert database from slite2 to sqlite3
+            mv "$VAR_DIR/$USER_DB" "$VAR_DIR/${USER_DB}2"
+            echo .dump| sqlite "$VAR_DIR/${USER_DB}2" | sqlite3 "$VAR_DIR/$USER_DB"
         fi
+        sqlite3 "$VAR_DIR/$USER_DB" < /usr/share/doc/benno-web/contrib/db-create.sql 2>/dev/null
+        #
+        sqlite3 "$VAR_DIR/$USER_DB" < /usr/share/doc/benno-web/contrib/db-update_2.0.1.sql 2>/dev/null
+        set -e
+
         chown $WWW_USER "$VAR_DIR/$USER_DB"
         chmod u=rw,g=r,o= "$VAR_DIR/$USER_DB"
     ;;
