@@ -244,11 +244,12 @@ class Application extends ApplicationConfig
 
         $this->TPL = new Smarty;
         $this->TPL->compile_check = true;
+
         if(array_key_exists('TEMPLATE_ROOT',$this->config)) {
-            $root_dir = posix_getcwd().'/'.$this->config['TEMPLATE_ROOT'];
+            $root_dir = getcwd().'/'.$this->config['TEMPLATE_ROOT'];
         }
         else {
-            $root_dir = posix_getcwd();
+            $root_dir = getcwd();
         }
         $this->TPL->template_dir = $root_dir.'/'.$this->module.'/templates';
 
