@@ -35,8 +35,6 @@
  $Id: DBAccess.php 27:516c6f1d1ed6 2012-02-19 15:01 +0100 mw $
 */
 
-require_once 'DB.php';
-
 /**
  * @package Model
  * @subpackage Persistence
@@ -71,30 +69,25 @@ class DBAccess
      */
     var $error;
 
-    /**
-     * Fehlerverhalten
-     *
-     * Wenn "dieError" auf TRUE gesetzt ist, beendet sich die
-     * Anwendung mit die() wenn bei einer Datenbankaktion ein Fehler
-     * aufgetreten ist. Transaktionen werden zurueck gesetzt.
-     *
-     * Defaultwert: TRUE
-     *
-     * @access public
-     */
-    var $dieError;
-
 
     /**
      * Datenbankobjekt
      *
-     * Speichert das PEAR::DB Objekt.
+     * Speichert das DBO Objekt.
      *
      * @access public
      */
     var $db;
 
 
+    /**
+     * Statement handle
+     *
+     * @access private
+     */
+    var $_sth;
+
+
     /**
      * Constructor
      *
@@ -114,33 +107,32 @@ class DBAccess
     {
 
         $this->error = FALSE;
-        $this->dieError = TRUE;
 
         $this->db_transaction = TRUE;
         if (strpos($dbType,'sqlite') === FALSE) {
             // if not sqlite
-            $options = array('debug' => 2);
-            $dns = "$dbType://$dbUser:$dbPassword@$host/$database";
-            $this->db = &DB::connect($dns,$options);
-        }
-        else {
-            $this->db = &DB::connect($dbType);
-            // The sqlite library returns arrays with table.attribute
-            // as key as default. This pragma forces the lib to return
-            // only the attribute names.
-            if (! DB::isError($this->db)) {
-                $this->db->query('PRAGMA short_column_names = 1');
+             $dsn = "$dbType:host=$host;dbname=$database";
+            try {
+                $this->db = new PDO($dsn,$dbUser,$dbPassword);
+            }
+            catch(PDOException $e)
+            {
+                error_log("[DBAccess] Cannot connect database($dsn): ".$e->getMessage());
             }
         }
-        if (DB::isError($this->db)) {
-            $this->error = TRUE;
-            echo " Verbindung zur Datenbank gescheitert.\n";
-            error_log(' Standard Message: '.$this->db->getMessage()."\n");
-            error_log(' DBMS/User Message: '.$this->db->getUserInfo()."\n");
-            error_log(' DBMS/Debug Message: '.$this->db->getDebugInfo()."\n");
-            die();
-        }
+        else {
+            // sqlite database
+            $dsn = $this->_prepare_sqlite_dsn($dbType);
 
+            try {
+                $this->db = new PDO($dsn);
+            }
+            catch(PDOException $e)
+            {
+                error_log("[DBAccess] Cannot connect database($dsn): ".$e->getMessage());
+            }
+        }
+        $this->db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
     }
 
 
@@ -159,15 +151,16 @@ class DBAccess
      */
     function query ($sql,$LOG_ERROR=true)
     {
-        $this->db->setFetchMode(DB_FETCHMODE_ASSOC);
-        $result =& $this->db->query($sql);
-        if (DB::isError($result)) {
-            $this->error = TRUE;
-            if ($LOG_ERROR == true) {
-                error_log(' DBMS/Debug Message: ' . $result->getDebugInfo() . '\n');
-            }
+        try {
+            $this->_sth = $this->db->prepare($sql);
+            $this->_sth->execute();
         }
-        return $result;
+        catch(PDOException $e){ 
+            if ($LOG_ERROR)
+                error_log(' [DBMS/query]: '.$e->getMessage());
+            throw new Exception('ERR_DBQUERY');
+        }
+        return new DBResult($this->_sth->fetchAll(PDO::FETCH_ASSOC));
     }
 
     
@@ -184,17 +177,11 @@ class DBAccess
     function fetchRow ($sql)
     {
         if (preg_match('/^(INSERT|UPDATE|DELETE)/i' ,$sql)) {
-            print "AFF: ".$this->db->affectedRows()."\n";
             return FALSE;
         }
-        $this->db->setFetchMode(DB_FETCHMODE_ASSOC);
-        $result =& $this->db->query($sql);
-        if (DB::isError($result)) {
-            $this->error = TRUE;
-            error_log(' DBMS/Debug Message: ' . $result->getDebugInfo() . '\n');
-			return FALSE;
-        }
-		return $result->fetchRow();
+        $this->_sth = $this->db->query($sql);
+        $row = $this->_sth->fetch(PDO::FETCH_ASSOC);
+		return $row;
     }
 
 
@@ -207,9 +194,8 @@ class DBAccess
     {
         if ($this->db_transaction) {
             $this->error = FALSE;
-            $this->db->query('BEGIN');
+            $this->db->beginTransaction();
         }
-
     }
 
 
@@ -227,11 +213,11 @@ class DBAccess
         $retval = TRUE;
         if ($this->db_transaction) {
             if ($this->error) {
-                $this->db->query('ROLLBACK');
+                $this->db->rollback();
                 $retval = FALSE;
             }
             else {
-                $this->db->query('COMMIT');
+                $this->db->commit();
             }
             $this->error = FALSE;
         }
@@ -249,7 +235,7 @@ class DBAccess
     function rollback ()
     {
         if ($this->db_transaction) {
-            $this->db->query('ROLLBACK');
+            $this->db->rollback();
         }
     }
 
@@ -262,8 +248,7 @@ class DBAccess
      */
     function quote ($str)
     {
-        //return $this->db->quoteSmart($str);
-        return $this->db->escapeSimple($str);
+        return $this->db->quote($str);
     }
 
 
@@ -279,12 +264,64 @@ class DBAccess
      */
     function affectedRows ()
     {
-        return $this->db->affectedRows();
+        return $this->_sth->rowCount();
+    }
+
+
+    /**
+     * check sqlite db file format and return connect string
+     *
+     */
+    function _prepare_sqlite_dsn($dsn)
+    {
+        $filepath = preg_replace('/^\S+?:/','',$dsn);
+        $dbformats = array('sqlite','sqlite2','sqlite3');
+        foreach ($dbformats as $dbformat) {
+            try {
+                $dbh = new PDO($dbformat.':'.$filepath);
+                $row = $dbh->query("SELECT * FROM sqlite_master WHERE type='table'");
+                $err = $dbh->errorCode();
+                if ($err == '0000') {
+                    return "$dbformat:$filepath";
+                }
+            }
+            catch(PDOException $e) {
+                error_log("[DBAccess/check_sqlite]: ".$e->getMessage());
+            }
+        }
     }
 
 }
 
-//$DB = new DBAccess($dbType,$dbUser,$dbPassword,$host,$database);
-//return $DB;
+
+class DBResult
+{
+    /**
+     *
+     * DBResult
+     *
+     * Compatiblity class implements the PEAR::DB_Result interface partially.
+     *
+     */
+    var $query_result;
+
+    function DBResult($query_result)
+    {
+        $this->query_result = $query_result;
+    }
+
+
+    function fetchRow()
+    {
+        $current_row = current($this->query_result);
+        next($this->query_result);
+        return $current_row;
+    }
+
+    function affectedRows()
+    {
+        return $this->_sth->rowCount();
+    }
+}
 
 ?>
