@@ -30,7 +30,9 @@
  * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
  * Suite 330, Boston, MA  02111-1307  USA
  */
-
+require_once 'model/AppState.php';
+$AppState = new AppState('searchMaskState',$USER->id,$App->getSession('searchMaskState'));
+$AppState->save();
 
 try {
     $Backend->destroy_bennorest_session();
