@@ -153,15 +153,25 @@ class Filter extends Persistence
     {
         $filter_attributes = array('From','To','Recipient','Sender');
 
+        $address_lowered = strtolower($address);
+
         $filter = '';
         foreach($filter_attributes as $attribute) {
             $filter .=  $attribute.':'.'*%3C'.$address.'%3E'.
                         ' '.
-                        $attribute.':'.$address.
+                        $attribute.':'.'*%3C'.$address_lowered.'%3E'.
+                        ' '.
+                        $attribute.':'.'*'.$address.
+                        ' '.
+                        $attribute.':'.'*'.$address_lowered.
                         ' '.
                         $attribute.':'.'*,'.$address.
                         ' '.
-                        $attribute.':'.$address.','.
+                        $attribute.':'.'*,'.$address_lowered.
+                        ' '.
+                        $attribute.':'.'*'.$address.','.
+                        ' '.
+                        $attribute.':'.'*'.$address_lowered.','.
                         ' '
                         ;
         }
